@@ -24,7 +24,7 @@
 /* include header */
 #include "result_thread.h"
 #include "mod_gearman.h"
-#include "gearman.h"
+#include "gearman_utils.h"
 
 /* specify event broker API version (required) */
 NEB_API_VERSION( CURRENT_NEB_API_VERSION )
@@ -180,11 +180,11 @@ int nebmodule_init( int flags, char *args, nebmodule *handle ) {
 static void register_neb_callbacks(void) {
 
     /* only if we have hostgroups defined or general hosts enabled */
-    if ( mod_gm_opt->do_hostchecks == GM_ENABLED && ( mod_gm_opt->hostgroups_num > 0 || mod_gm_opt->hosts == GM_ENABLED ))
+    if ( mod_gm_opt->do_hostchecks == GM_ENABLED && ( mod_gm_opt->hostgroups_num > 0 || mod_gm_opt->hosts == GM_ENABLED || mod_gm_opt->queue_cust_var ))
         neb_register_callback( NEBCALLBACK_HOST_CHECK_DATA,    gearman_module_handle, 0, handle_host_check );
 
     /* only if we have groups defined or general services enabled */
-    if ( mod_gm_opt->servicegroups_num > 0 || mod_gm_opt->hostgroups_num > 0 || mod_gm_opt->services == GM_ENABLED )
+    if ( mod_gm_opt->servicegroups_num > 0 || mod_gm_opt->hostgroups_num > 0 || mod_gm_opt->services == GM_ENABLED || mod_gm_opt->queue_cust_var )
         neb_register_callback( NEBCALLBACK_SERVICE_CHECK_DATA, gearman_module_handle, 0, handle_svc_check );
 
     if ( mod_gm_opt->events == GM_ENABLED )
@@ -477,6 +477,9 @@ static int handle_host_check( int event_type, void *data ) {
     check_result * chk_result;
     int check_options;
     struct timeval core_time;
+    struct tm next_check;
+    char buffer1[GM_BUFFERSIZE];
+
     gettimeofday(&core_time,NULL);
 
     gm_log( GM_LOG_TRACE, "handle_host_check(%i)\n", event_type );
@@ -576,9 +579,7 @@ static int handle_host_check( int event_type, void *data ) {
 
     /* log latency */
     if(mod_gm_opt->debug_level >= GM_LOG_DEBUG) {
-        struct tm next_check;
         localtime_r(&hst->next_check, &next_check);
-        char buffer1[GM_BUFFERSIZE];
         strftime(buffer1, sizeof(buffer1), "%Y-%m-%d %H:%M:%S", &next_check );
         gm_log( GM_LOG_DEBUG, "host: '%s', next_check is at %s, latency so far: %i\n", hst->name, buffer1, ((int)core_time.tv_sec - (int)hst->next_check));
     }
@@ -647,6 +648,9 @@ static int handle_svc_check( int event_type, void *data ) {
     int prio = GM_JOB_PRIO_LOW;
     check_result * chk_result;
     struct timeval core_time;
+    struct tm next_check;
+    char buffer1[GM_BUFFERSIZE];
+
     gettimeofday(&core_time,NULL);
 
     gm_log( GM_LOG_TRACE, "handle_svc_check(%i, data)\n", event_type );
@@ -744,9 +748,7 @@ static int handle_svc_check( int event_type, void *data ) {
 
     /* log latency */
     if(mod_gm_opt->debug_level >= GM_LOG_DEBUG) {
-        struct tm next_check;
         localtime_r(&svc->next_check, &next_check);
-        char buffer1[GM_BUFFERSIZE];
         strftime(buffer1, sizeof(buffer1), "%Y-%m-%d %H:%M:%S", &next_check );
         gm_log( GM_LOG_DEBUG, "service: '%s' - '%s', next_check is at %s, latency so far: %i\n", svcdata->host_name, svcdata->service_description, buffer1, ((int)core_time.tv_sec - (int)svc->next_check));
     }
@@ -1124,18 +1126,19 @@ int handle_perfdata(int event_type, void *data) {
 
 /* handle generic exports */
 int handle_export(int callback_type, void *data) {
-    int i;
+    int i, debug_level_orig, return_code;
     char * buffer;
     char * type;
     char * event_type;
-    temp_buffer[0]          = '\x0';
-    int debug_level_orig    = mod_gm_opt->debug_level;
-    mod_gm_opt->debug_level = -1;
-    int return_code         = 0;
     nebstruct_log_data          * nld;
     nebstruct_process_data      * npd;
     nebstruct_timed_event_data  * nted;
 
+    temp_buffer[0]          = '\x0';
+    mod_gm_opt->debug_level = -1;
+    debug_level_orig    = mod_gm_opt->debug_level;
+    return_code         = 0;
+
     /* what type of event/data do we have? */
     switch (callback_type) {
         case NEBCALLBACK_RESERVED0:                         /*  0 */
